pub struct Params {
pub alpha: f64,
pub beta: f64,
pub gamma: f64,
pub phi: f64,
}Expand description
The parameters of an ETS model.
Fields
alpha: f64The value of the smoothing parameter for the level.
If alpha = 0, the level will not change over time.
Conversely, if alpha = 1 the level will update similarly to a random walk process.
beta: f64The value of the smoothing parameter for the slope.
If beta = 0, the slope will not change over time.
Conversely, if beta = 1 the slope will have no memory of past slopes.
gamma: f64The value of the smoothing parameter for the seasonal pattern.
If gamma = 0, the seasonal pattern will not change over time.
Conversely, if gamma = 1 the seasonality will have no memory of past seasonal periods.
phi: f64The value of the dampening parameter for the slope.
If phi = 0, the slope will be dampened immediately (no slope).
Conversely, if phi = 1 the slope will not be dampened.